#import "Global.h"
#import "MainViewController.h"
#import "MainView.h"
#import "GraphView.h"

@implementation MainViewController

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
	if (self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil]) {
		// Custom initialization
	}
	return self;
}

- (void)viewDidLoad {
	/* 오늘 날짜를 구한다. */
	NSDateComponents *today = [[NSCalendar currentCalendar] 
					   components:(NSYearCalendarUnit | NSMonthCalendarUnit |  NSDayCalendarUnit) 
					   fromDate:[NSDate date]];
	
	/* 현재 날짜 설정 */
	[graphView setCurrentDate:[today year] 
					  atMonth:[today month] 
						atDay:[today day]];

	/* 생년월일 설정 */
	[graphView setBirthDate:[[NSUserDefaults standardUserDefaults] integerForKey:US_BIRTHYEAR_KEY] 
					  atMonth:[[NSUserDefaults standardUserDefaults] integerForKey:US_BIRTHMONTH_KEY] 
						atDay:[[NSUserDefaults standardUserDefaults] integerForKey:US_BIRTHDAY_KEY]];

	/* 그래프를 그리고 UI를 설정한다. */
	[graphView resetBiorhythmData];
	[self updateInfoUI];
	
	/* 환경설정에서 생일이 변경되었을 때를 위해 옵저버로 등록 */
	[[NSNotificationCenter defaultCenter] addObserver:self
											 selector:@selector(birthdayChanged:)
												 name:NM_BIRTHDAYCHANGED
											   object:nil];
}

- (void)updateInfoUI {
	/* 하단 타이틀에 현재 날짜를 출력 */
	NSDateComponents *date = [graphView currentDate];
	[currentDate setTitle:[NSString stringWithFormat:@"%d.%02d.%02d", 
						   [date year], [date month], [date day]]];
	
	float *bioValue = [graphView getBiorhythmDayData:[date day]];
	int value1 = (int)ceil(bioValue[0]);
	int value2 = (int)ceil(bioValue[1]);
	int value3 = (int)ceil(bioValue[2]);
	
	/* 각 바이오리듬 값 출력 */
	[value_1 setText:[NSString stringWithFormat:@"%d", value1]];
	[value_2 setText:[NSString stringWithFormat:@"%d", value2]];
	[value_3 setText:[NSString stringWithFormat:@"%d", value3]];
	
	/* mainView에 현재 설정된 값을 알려주고, 바가 다시 그려지도록 한다. */
	[mainView setData:value1 secondValue:value2 thirdValue:value3];
	[mainView setNeedsDisplay];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
	// Return YES for supported orientations
	return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

- (void)didReceiveMemoryWarning {
	[super didReceiveMemoryWarning]; // Releases the view if it doesn't have a superview
	// Release anything that's not essential, such as cached data
}

- (void)dealloc {
	[super dealloc];
}

- (void)birthdayChanged:(NSNotification *)note
{
	/* 생일이 변경되었을 때 다시 설정하고 그려지도록 한다. */
	[graphView setBirthDate:[[NSUserDefaults standardUserDefaults] integerForKey:US_BIRTHYEAR_KEY] 
					  atMonth:[[NSUserDefaults standardUserDefaults] integerForKey:US_BIRTHMONTH_KEY] 
						atDay:[[NSUserDefaults standardUserDefaults] integerForKey:US_BIRTHDAY_KEY]];
	
	[graphView resetBiorhythmData];
	[self updateInfoUI];
}		


- (IBAction) navigationButtonClicked:(id)sender {
	/* 사용자가 날짜 이동 버튼을 클릭하였을 경우 처리 */
	[graphView changeDate:[sender tag]];
	[self updateInfoUI];
}

@end